==> dde-shell_2.0.15.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Tümünü Temizle</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>More</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NotifyCenter</name>
    <message>
        <source>No recent notifications</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Bildirim Merkezi</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Tümünü Temizle</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>More</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Sabitlemeyi kaldır</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Sabitle</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Bildirim Ayarı</translation>
    </message>
</context>
<context>
    <name>NotifyViewDelegate</name>
    <message>
        <source>Clean All</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Hemen şimdi</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.19.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Tümünü Temizle</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation>Katla</translation>
    </message>
    <message>
        <source>More</source>
        <translation>Daha</translation>
    </message>
</context>
<context>
    <name>NotifyCenter</name>
    <message>
        <source>No recent notifications</source>
        <translation>Son bildirim yok</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Bildirim Merkezi</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Tümünü Temizle</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation>Katla</translation>
    </message>
    <message>
        <source>More</source>
        <translation>Daha</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Sabitlemeyi kaldır</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Sabitle</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Bildirim Ayarı</translation>
    </message>
</context>
<context>
    <name>NotifyViewDelegate</name>
    <message>
        <source>Clean All</source>
        <translation>Tümünü Temizle</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Hemen şimdi</translation>
    </message>
</context>
</TS>
